==> google-cloud-sdk-492.0.0.tgz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/logging_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .log_entry import (
    LogEntry,
    LogEntryOperation,
    LogEntrySourceLocation,
    LogErrorGroup,
    LogSplit,
)
from .logging import (
    DeleteLogRequest,
    ListLogEntriesRequest,
    ListLogEntriesResponse,
    ListLogsRequest,
    ListLogsResponse,
    ListMonitoredResourceDescriptorsRequest,
    ListMonitoredResourceDescriptorsResponse,
    TailLogEntriesRequest,
    TailLogEntriesResponse,
    WriteLogEntriesPartialErrors,
    WriteLogEntriesRequest,
    WriteLogEntriesResponse,
)
from .logging_config import (
    BigQueryDataset,
    BigQueryOptions,
    BucketMetadata,
    CmekSettings,
    CopyLogEntriesMetadata,
    CopyLogEntriesRequest,
    CopyLogEntriesResponse,
    CreateBucketRequest,
    CreateExclusionRequest,
    CreateLinkRequest,
    CreateSavedQueryRequest,
    CreateSinkRequest,
    CreateViewRequest,
    DeleteBucketRequest,
    DeleteExclusionRequest,
    DeleteLinkRequest,
    DeleteSavedQueryRequest,
    DeleteSinkRequest,
    DeleteViewRequest,
    GetBucketRequest,
    GetCmekSettingsRequest,
    GetExclusionRequest,
    GetLinkRequest,
    GetSavedQueryRequest,
    GetSettingsRequest,
    GetSinkRequest,
    GetViewRequest,
    IndexConfig,
    Link,
    LinkMetadata,
    ListBucketsRequest,
    ListBucketsResponse,
    ListExclusionsRequest,
    ListExclusionsResponse,
    ListLinksRequest,
    ListLinksResponse,
    ListRecentQueriesRequest,
    ListRecentQueriesResponse,
    ListSavedQueriesRequest,
    ListSavedQueriesResponse,
    ListSinksRequest,
    ListSinksResponse,
    ListViewsRequest,
    ListViewsResponse,
    LocationMetadata,
    LogBucket,
    LogExclusion,
    LoggingQuery,
    LogSink,
    LogView,
    OpsAnalyticsQuery,
    RecentQuery,
    SavedQuery,
    Settings,
    UndeleteBucketRequest,
    UpdateBucketRequest,
    UpdateCmekSettingsRequest,
    UpdateExclusionRequest,
    UpdateSavedQueryRequest,
    UpdateSettingsRequest,
    UpdateSinkRequest,
    UpdateViewRequest,
    IndexType,
    LifecycleState,
    OperationState,
)
from .logging_metrics import (
    CreateLogMetricRequest,
    DeleteLogMetricRequest,
    GetLogMetricRequest,
    ListLogMetricsRequest,
    ListLogMetricsResponse,
    LogMetric,
    UpdateLogMetricRequest,
)

__all__ = (
    'LogEntry',
    'LogEntryOperation',
    'LogEntrySourceLocation',
    'LogErrorGroup',
    'LogSplit',
    'DeleteLogRequest',
    'ListLogEntriesRequest',
    'ListLogEntriesResponse',
    'ListLogsRequest',
    'ListLogsResponse',
    'ListMonitoredResourceDescriptorsRequest',
    'ListMonitoredResourceDescriptorsResponse',
    'TailLogEntriesRequest',
    'TailLogEntriesResponse',
    'WriteLogEntriesPartialErrors',
    'WriteLogEntriesRequest',
    'WriteLogEntriesResponse',
    'BigQueryDataset',
    'BigQueryOptions',
    'BucketMetadata',
    'CmekSettings',
    'CopyLogEntriesMetadata',
    'CopyLogEntriesRequest',
    'CopyLogEntriesResponse',
    'CreateBucketRequest',
    'CreateExclusionRequest',
    'CreateLinkRequest',
    'CreateSavedQueryRequest',
    'CreateSinkRequest',
    'CreateViewRequest',
    'DeleteBucketRequest',
    'DeleteExclusionRequest',
    'DeleteLinkRequest',
    'DeleteSavedQueryRequest',
    'DeleteSinkRequest',
    'DeleteViewRequest',
    'GetBucketRequest',
    'GetCmekSettingsRequest',
    'GetExclusionRequest',
    'GetLinkRequest',
    'GetSavedQueryRequest',
    'GetSettingsRequest',
    'GetSinkRequest',
    'GetViewRequest',
    'IndexConfig',
    'Link',
    'LinkMetadata',
    'ListBucketsRequest',
    'ListBucketsResponse',
    'ListExclusionsRequest',
    'ListExclusionsResponse',
    'ListLinksRequest',
    'ListLinksResponse',
    'ListRecentQueriesRequest',
    'ListRecentQueriesResponse',
    'ListSavedQueriesRequest',
    'ListSavedQueriesResponse',
    'ListSinksRequest',
    'ListSinksResponse',
    'ListViewsRequest',
    'ListViewsResponse',
    'LocationMetadata',
    'LogBucket',
    'LogExclusion',
    'LoggingQuery',
    'LogSink',
    'LogView',
    'OpsAnalyticsQuery',
    'RecentQuery',
    'SavedQuery',
    'Settings',
    'UndeleteBucketRequest',
    'UpdateBucketRequest',
    'UpdateCmekSettingsRequest',
    'UpdateExclusionRequest',
    'UpdateSavedQueryRequest',
    'UpdateSettingsRequest',
    'UpdateSinkRequest',
    'UpdateViewRequest',
    'IndexType',
    'LifecycleState',
    'OperationState',
    'CreateLogMetricRequest',
    'DeleteLogMetricRequest',
    'GetLogMetricRequest',
    'ListLogMetricsRequest',
    'ListLogMetricsResponse',
    'LogMetric',
    'UpdateLogMetricRequest',
)

==> google-cloud-sdk-541.0.0.tgz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/logging_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .log_entry import (
    AppHub,
    AppHubApplication,
    AppHubService,
    AppHubWorkload,
    LogEntry,
    LogEntryOperation,
    LogEntrySourceLocation,
    LogErrorGroup,
    LogSplit,
)
from .logging import (
    DeleteLogRequest,
    ListLogEntriesRequest,
    ListLogEntriesResponse,
    ListLogsRequest,
    ListLogsResponse,
    ListMonitoredResourceDescriptorsRequest,
    ListMonitoredResourceDescriptorsResponse,
    TailLogEntriesRequest,
    TailLogEntriesResponse,
    WriteLogEntriesPartialErrors,
    WriteLogEntriesRequest,
    WriteLogEntriesResponse,
)
from .logging_config import (
    BigQueryDataset,
    BigQueryOptions,
    BucketMetadata,
    CmekSettings,
    CopyLogEntriesMetadata,
    CopyLogEntriesRequest,
    CopyLogEntriesResponse,
    CreateBucketRequest,
    CreateExclusionRequest,
    CreateLinkRequest,
    CreateLogScopeRequest,
    CreateSavedQueryRequest,
    CreateSinkRequest,
    CreateViewRequest,
    DeleteBucketRequest,
    DeleteExclusionRequest,
    DeleteLinkRequest,
    DeleteLogScopeRequest,
    DeleteSavedQueryRequest,
    DeleteSinkRequest,
    DeleteViewRequest,
    GetBucketRequest,
    GetCmekSettingsRequest,
    GetExclusionRequest,
    GetLinkRequest,
    GetLogScopeRequest,
    GetSavedQueryRequest,
    GetSettingsRequest,
    GetSinkRequest,
    GetViewRequest,
    IndexConfig,
    Link,
    LinkMetadata,
    ListBucketsRequest,
    ListBucketsResponse,
    ListExclusionsRequest,
    ListExclusionsResponse,
    ListLinksRequest,
    ListLinksResponse,
    ListLogScopesRequest,
    ListLogScopesResponse,
    ListRecentQueriesRequest,
    ListRecentQueriesResponse,
    ListSavedQueriesRequest,
    ListSavedQueriesResponse,
    ListSinksRequest,
    ListSinksResponse,
    ListViewsRequest,
    ListViewsResponse,
    LocationMetadata,
    LogBucket,
    LogExclusion,
    LoggingQuery,
    LogScope,
    LogSink,
    LogView,
    OpsAnalyticsQuery,
    RecentQuery,
    SavedQuery,
    Settings,
    UndeleteBucketRequest,
    UpdateBucketRequest,
    UpdateCmekSettingsRequest,
    UpdateExclusionRequest,
    UpdateLogScopeRequest,
    UpdateSavedQueryRequest,
    UpdateSettingsRequest,
    UpdateSinkRequest,
    UpdateViewRequest,
    IndexType,
    LifecycleState,
    OperationState,
)
from .logging_metrics import (
    CreateLogMetricRequest,
    DeleteLogMetricRequest,
    GetLogMetricRequest,
    ListLogMetricsRequest,
    ListLogMetricsResponse,
    LogMetric,
    UpdateLogMetricRequest,
)

__all__ = (
    'AppHub',
    'AppHubApplication',
    'AppHubService',
    'AppHubWorkload',
    'LogEntry',
    'LogEntryOperation',
    'LogEntrySourceLocation',
    'LogErrorGroup',
    'LogSplit',
    'DeleteLogRequest',
    'ListLogEntriesRequest',
    'ListLogEntriesResponse',
    'ListLogsRequest',
    'ListLogsResponse',
    'ListMonitoredResourceDescriptorsRequest',
    'ListMonitoredResourceDescriptorsResponse',
    'TailLogEntriesRequest',
    'TailLogEntriesResponse',
    'WriteLogEntriesPartialErrors',
    'WriteLogEntriesRequest',
    'WriteLogEntriesResponse',
    'BigQueryDataset',
    'BigQueryOptions',
    'BucketMetadata',
    'CmekSettings',
    'CopyLogEntriesMetadata',
    'CopyLogEntriesRequest',
    'CopyLogEntriesResponse',
    'CreateBucketRequest',
    'CreateExclusionRequest',
    'CreateLinkRequest',
    'CreateLogScopeRequest',
    'CreateSavedQueryRequest',
    'CreateSinkRequest',
    'CreateViewRequest',
    'DeleteBucketRequest',
    'DeleteExclusionRequest',
    'DeleteLinkRequest',
    'DeleteLogScopeRequest',
    'DeleteSavedQueryRequest',
    'DeleteSinkRequest',
    'DeleteViewRequest',
    'GetBucketRequest',
    'GetCmekSettingsRequest',
    'GetExclusionRequest',
    'GetLinkRequest',
    'GetLogScopeRequest',
    'GetSavedQueryRequest',
    'GetSettingsRequest',
    'GetSinkRequest',
    'GetViewRequest',
    'IndexConfig',
    'Link',
    'LinkMetadata',
    'ListBucketsRequest',
    'ListBucketsResponse',
    'ListExclusionsRequest',
    'ListExclusionsResponse',
    'ListLinksRequest',
    'ListLinksResponse',
    'ListLogScopesRequest',
    'ListLogScopesResponse',
    'ListRecentQueriesRequest',
    'ListRecentQueriesResponse',
    'ListSavedQueriesRequest',
    'ListSavedQueriesResponse',
    'ListSinksRequest',
    'ListSinksResponse',
    'ListViewsRequest',
    'ListViewsResponse',
    'LocationMetadata',
    'LogBucket',
    'LogExclusion',
    'LoggingQuery',
    'LogScope',
    'LogSink',
    'LogView',
    'OpsAnalyticsQuery',
    'RecentQuery',
    'SavedQuery',
    'Settings',
    'UndeleteBucketRequest',
    'UpdateBucketRequest',
    'UpdateCmekSettingsRequest',
    'UpdateExclusionRequest',
    'UpdateLogScopeRequest',
    'UpdateSavedQueryRequest',
    'UpdateSettingsRequest',
    'UpdateSinkRequest',
    'UpdateViewRequest',
    'IndexType',
    'LifecycleState',
    'OperationState',
    'CreateLogMetricRequest',
    'DeleteLogMetricRequest',
    'GetLogMetricRequest',
    'ListLogMetricsRequest',
    'ListLogMetricsResponse',
    'LogMetric',
    'UpdateLogMetricRequest',
)
